@@ -1,6 +1,6 @@
 /*
 **  GNU Pth - The GNU Portable Threads
-**  Copyright (c) 1999-2004 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 1999-2005 Ralf S. Engelschall <rse@engelschall.com>
 **
 **  This file is part of GNU Pth, a non-preemptive thread scheduling
 **  library which can be found at http://www.gnu.org/software/pth/.
@@ -121,8 +121,8 @@ dopr(
     ch = *format++;
 
     if (maxlen == -1)
-        /* possible maximum size in a size_t */
-        maxlen = (~(1<<((sizeof(size_t)*8)-2)));
+        /* possible maximum size in a size_t (size_t unfortunately could be signed) */
+        maxlen = (~(((size_t)1)<<((sizeof(size_t)*8)-1)));
 
     while (state != DP_S_DONE) {
         if ((ch == NUL) || (currlen >= maxlen))
